<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use DB;

use App\ResultItem;

class ResultItemController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    function __construct()
    {
         $this->middleware('permission:resultitem-list|resultitem-create|resultitem-edit|resultitem-delete', ['only' => ['index','store']]);
         $this->middleware('permission:resultitem-create', ['only' => ['create','store']]);
         $this->middleware('permission:resultitem-edit', ['only' => ['edit','update']]);
         $this->middleware('permission:resultitem-delete', ['only' => ['destroy']]);

        // TinyMCE
        $tm[0]['selector'] = 'itemBody';
        $tm[0]['upload_url'] = 'results';
        $tm[0]['field_height'] = '300';

        $this->tm = $tm;
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $this->validate($request, [
            'title' => 'required|unique:result_items,title',
        ]);

        $resultItem = ResultItem::create([
            'title' => $request->input('title'),
            'body' => request('body'),
            'result_group_id' => $request->input('result_group_id'),
            'item_order' => $request->input('item_order')
        ]);
    
        return redirect()->route('results.index')
                        ->with('success','Group item created successfully');
    }

/**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        $this->validate($request, [
            'title' => 'required',
        ]);
    
        $resultItem = ResultItem::find($id);
        $resultItem->title = $request->input('title');
        $resultItem->result_group_id = $request->input('result_group_id');
        $resultItem->item_order = $request->input('item_order');
        $resultItem->body = $request->input('body');
        $resultItem->save();
    
        return redirect()->route('results.index')
                        ->with('success','Group item updated successfully');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        DB::table("result_items")->where('id',$id)->delete();

        return redirect()->route('results.index')
                        ->with('success','Item deleted successfully');
    }
}