<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;

use DB;
use Session;
use Storage;
use Carbon\Carbon;
use Auth;

use App\Submission;

class SubmissionController extends Controller
{

    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    function __construct()
    {
         $this->middleware('permission:submission-list|submission-create|submission-edit|submission-delete', ['only' => ['index','store']]);
         $this->middleware('permission:submission-create', ['only' => ['create','store']]);
         $this->middleware('permission:submission-edit', ['only' => ['edit','update']]);
         $this->middleware('permission:submission-delete', ['only' => ['destroy']]);

        // Upload folder
        $this->folder = 'submissions';
    }

    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        // page header
        $title = __('dashboard.title_submissions');
        $route = null;
        $pageType = 'index';
        $canCreate = 'submission-create';
        $canExport = null;

        $submissionStatuses = Submission::submissionStatus();

        $submissions = Submission::orderBy('created_at','DESC')->paginate(10);

        return view('submissions.index',compact('title','route','pageType','canCreate','canExport',
                                            'submissions','submissionStatuses'));
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        DB::table("submissions")->where('id',$id)->delete();

        return redirect()->route('submissions.index')
                        ->with('success','Submission deleted successfully');
    }

    /**
     * Update submission status.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function updateStatus(Request $request)
    {
        
        $id = $request->input('id');
        $status = $request->input('status');
        $points = $request->input('points');

        $submissionUpdate = Submission::where('id',$id)->update([
            'status' => $status,
            'points' => $points
        ]);

        if($submissionUpdate):

            $msg = __('dashboard.msg_submission_update_ok');

        else:

            $msg = __('dashboard.msg_err');

        endif;

        return response()->json(['msg' => $msg], 200);
    }

    /**
     * Search submissions.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function search(Request $request)
    {
        // page header
        $title = __('dashboard.title_submissions');
        $route = null;
        $pageType = 'index';

        $submissionStatuses = Submission::submissionStatus();

        $builder = DB::table('submissions as s')
                        ->join('users as u','u.id','s.user_id');

        if(null !== $request->input('srch_all')):

            $search_all = $request->input('srch_all');

            $builder->where(function($query) use ($search_all){
                $query->whereRaw('LOWER(s.id) LIKE ? ',trim('%'.strtolower($search_all)).'%')
                ->orWhereRaw('LOWER(s.bi) LIKE ? ',trim('%'.mb_strtolower($search_all)).'%')
                ->orWhereRaw('LOWER(u.name) LIKE ? ',trim('%'.mb_strtolower($search_all)).'%')
                ->orWhereRaw('LOWER(u.last_name) LIKE ? ',trim('%'.mb_strtolower($search_all)).'%');
            });

        endif;

        if(null !== $request->input('srch_status')):

            $search_status = $request->input('srch_status');

            $builder->where('s.status',$search_status);

        endif;

        if(null !== $request->input('srch_from')):

            $search_date_from = date('Y-m-d', strtotime($request->input('srch_from')));

            $builder->where('s.created_at','>',$search_date_from);

        endif;

        if(null !== $request->input('srch_to')):

            $search_date_to = date('Y-m-d', strtotime($request->input('srch_to'). ' +1 day'));

            $builder->where('s.created_at','<=',$search_date_to);

        endif;

        $submissions = $builder->select(
            's.id as id',
            's.user_id as user_id',
            'u.name as user_name',
            'u.last_name as user_last_name',
            's.bi as bi',
            's.points as points',
            's.source as source',
            's.image as image',
            's.status as status',
            's.created_at as created_at',
            's.updated_at as updated_at'
        )
        ->orderBy('s.created_at','DESC')
        ->paginate(10);

        Session::flashInput($request->input());

        return view('submissions.search',compact('title','route','pageType',
                                            'submissions','submissionStatuses'));
        
        
    }
}
