<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use DB;

use App\ThemePosition;

class ThemePositionController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    function __construct()
    {
         $this->middleware('permission:themeposition-list|themeposition-create|themeposition-edit|themeposition-delete', ['only' => ['index','store']]);
         $this->middleware('permission:themeposition-create', ['only' => ['create','store']]);
         $this->middleware('permission:themeposition-edit', ['only' => ['edit','update']]);
         $this->middleware('permission:themeposition-delete', ['only' => ['destroy']]);

        // TinyMCE
        $tm[0]['selector'] = 'description';
        $tm[0]['upload_url'] = 'theme-positions';
        $tm[0]['field_height'] = '300';

        $this->tm = $tm;
    }

    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        // page header
        $title = __('dashboard.title_theme_positions');
        $route = route('theme-positions.create');
        $pageType = 'index';
        $canCreate = 'themeposition-create';
        $canExport = null;

        $themePositions = ThemePosition::orderBy('id','DESC')->paginate(10);

        return view('theme-positions.index',compact('title','route','pageType','canCreate','canExport',
                                                        'themePositions'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        // page header
        $title = __('dashboard.title_theme_positions');
        $route = route('theme-positions.index');
        $pageType = 'create';

        $tm = $this->tm;

        return view('theme-positions.create',compact('title','route','pageType','tm'));
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $this->validate($request, [
            'name' => 'required|unique:theme_positions,name',
        ]);
    
        $themePosition = ThemePosition::create([
            'name' => $request->input('name'),
            'description' => $request->input('description')
        ]);
    
        return redirect()->route('theme-positions.index')
                        ->with('success','Theme position created successfully');
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        // page header
        $title = __('dashboard.title_theme_positions');
        $route = route('theme-positions.index');
        $pageType = 'show';

        $themePosition = ThemePosition::find($id);
    
        return view('theme-positions.show',compact('title','route','pageType',
                                            'themePosition'));
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        // page header
        $title = __('dashboard.title_theme_positions');
        $route = route('theme-positions.index');
        $pageType = 'edit';

        // TinyMCE
        $tm = $this->tm;

        $themePosition = ThemePosition::find($id);
    
        return view('theme-positions.edit',compact('title','route','pageType','tm',
                                                    'themePosition'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        $this->validate($request, [
            'name' => 'required',
        ]);
    
        $themePosition = ThemePosition::find($id);
        $themePosition->name = $request->input('name');
        $themePosition->description = $request->input('description');
        $themePosition->save();
    
        return redirect()->route('theme-positions.index')
                        ->with('success','Theme position updated successfully');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        DB::table("theme_positions")->where('id',$id)->delete();
        return redirect()->route('theme-positions.index')
                        ->with('success','Theme position deleted successfully');
    }
}
