@extends('dashboard.index')

@section('contentDashboard')

    @include('dashboard.page_header')

    @if (count($errors) > 0)
        <div class="alert alert-danger">
            <ul>
            @foreach ($errors->all() as $error)
                <li>{{ $error }}</li>
            @endforeach
            </ul>
        </div>
    @endif

    <div class="row">

        <div class="col col-xl-12">

            {!! Form::model($categoryDATA, ['method' => 'PATCH','route' => ['categories.update', $categoryDATA->id],'enctype'=>'multipart/form-data']) !!}

            <div class="card">

                <div class="card-body">

                    <div class="row">

                        <div class="col-xl-8">

                            <div class="row">
                                <div class="col mb-4">
                                    <div class="form-outline">
                                        <input type="text" id="formControlDefault" class="form-control" name="name" onBlur="convertToSlug('name')" value="{{ $categoryDATA->name }}" />
                                        <label class="form-label" for="formControlDefault">@lang('dashboard.title_name')</label>
                                    </div>
                                </div>
                            </div>

                            <div class="row">
                                <div class="col mb-4">
                                    <label class="fw-bold">@lang('dashboard.title_parent_category')</label>
                                    <select class="form-select" aria-label="Parent Category" name="parent_id">
                                        <option value="" selected>@lang('dashboard.title_choose')</option>
                                        @foreach ($categories_SEL as $category)
                                            @if ($category->parent_id == null)
                                            <option value="{{ $category->id }}" {{ ($category['active'] == '0')? 'disabled':'' }} {{ ($categoryDATA->parent_id == $category->id )? 'selected':'' }}>{{ $category->name }}</option>
                                            @endif
                                            @foreach ($category->childrenCategories as $childCategory)
                                                @include(
                                                    'categories.child_category',
                                                    [
                                                        'child_category' => $childCategory,
                                                        'parent_url' => $category->slug,
                                                        'before' => '-',
                                                        'selected_cat' => $categoriesForAttribute
                                                    ]
                                                    )
                                            @endforeach
                                        @endforeach
                                      </select>
                                </div>
                            </div>

                            <div class="row">
                                <div class="col">
                                    <div class="form-group">
                                        <label class="fw-bold">@lang('dashboard.title_description'):</label>
                                        <textarea id="description" name="description">{!! $categoryDATA->description !!}</textarea>
                                    </div>
                                </div>
                            </div>

                        </div>

                        <div class="col-xl-4">

                            <hr class="d-block d-xl-none">

                            <div class="row">

                                <div class="col-md-6">

                                    <div class="row">
                                        <div class="col mb-4 ml-4">
                                            <div class="form-check form-switch">
                                                <input class="form-check-input" type="checkbox" role="switch" id="categoryActive" name="active" value="1" {{ ($categoryDATA->active == 1)? 'checked':''}} />
                                                <label class="form-check-label" for="categoryActive">@lang('dashboard.title_active')</label>
                                            </div>
                                        </div>
                                    </div>

                                </div>

                                <div class="col-md-6">

                                    <div class="row">
                                        <div class="col-12 mb-4">
                                            <div class="form-outline">
                                                <input type="text" id="formControlDefault" class="form-control" name="cat_order" value="{{ $categoryDATA->cat_order }}" />
                                                <label class="form-label" for="formControlDefault">@lang('dashboard.title_display_order')</label>
                                            </div>
                                        </div>
                                    </div>

                                </div>

                            </div>

                            <div class="row">
                                <div class="col mb-4">
                                    <div class="form-outline">
                                        <input type="text" id="formControlDefault" class="form-control" name="slug"  value="{{ $categoryDATA->slug }}" />
                                        <label class="form-label" for="formControlDefault">@lang('dashboard.title_slug')</label>
                                    </div>
                                </div>
                            </div>

                            <hr>

                            <div class="row">
                                <div class="col mb-4">
                                    <label class="form-label fw-bold" for="categoryImage">@lang('dashboard.title_image')</label>
                                    <input type="file" class="form-control" id="categoryImage" name="cat_image"/>
                                </div>
                            </div>

                            @if($categoryDATA->cat_image != null)
                            <div class="row">
                                <div class="col mb-4">
                                
                                    <div class="dsplIMG">
                                        <img src="/storage/categories/{{ $categoryDATA->cat_image }}" class="img-fluid" title="{{ $categoryDATA->name }}">
                                    </div>
                                    <div id="imgDELETE" class="btn btn-danger btn-sm mt-2" onclick="delIMG('categories','cat_image',{{ $categoryDATA->id }})"><i class="far fa-trash-alt"></i></div>

                                </div>
                            </div>
                            @endif

                            <hr>

                            <div class="row">
                                <div class="col">
                                    <div class="form-group">
                                        <label class="fw-bold" for="metaDesc">@lang('dashboard.title_meta_description')</label>
                                        <textarea class="form-control rounded-0" id="metaDesc" rows="5" name="meta_description">{{  $categoryDATA->meta_description }}</textarea>
                                      </div>
                                </div>
                            </div>

                            <div class="row">
                                <div class="col">
                                    <div class="form-group">
                                        <label class="fw-bold" for="metaDesc">@lang('dashboard.title_meta_keywords')</label>
                                        <textarea class="form-control rounded-0" id="metaDesc" rows="5" name="meta_keywords">{{  $categoryDATA->meta_keywords }}</textarea>
                                      </div>
                                </div>
                            </div>

                        </div>

                    </div>

                </div>

                <div class="card-footer">

                    <div class="row">
                        <div class="col text-right">
                            <button type="submit" class="btn btn-primary px-5 col col-lg-6">@lang('dashboard.btn_submit')</button>
                        </div>
                    </div>

                </div>

            </div>

            {!! Form::close() !!}

        </div>

    </div>

    <tinymce
        :data_tm = "{{ json_encode($tm) }}"
    >
    </tinymce>

@endsection